from app.models.database_connection import connect_db
import pyodbc
from datetime import datetime

# def checkout_cart(user_id, address, delivery):
#     try:
#         connection = connect_db()
#         # Ensure that all operations are executed as a single transaction
#         connection.autocommit = False
#         cursor = connection.cursor()

#         # Fetch cart items for the user
#         cursor.execute("SELECT ProductID, CartQuantity, UnitPrice, CartQuantity * UnitPrice AS TotalItemPrice FROM ShoppingCart WHERE UserID = ?", (user_id,))
#         cart_items = cursor.fetchall()

#         if not cart_items:
#             return {"error": "No items in the cart to checkout."}

#         # Insert a new order group
#         total_price = sum(item.TotalItemPrice for item in cart_items)
#         cursor.execute("INSERT INTO OrderGroup (Transaction_date, Address, Delivery, CustomerID, TotalPrice) VALUES (?, ?, ?, ?, ?)", (datetime.now(), address, delivery, user_id, total_price))
#         transaction_id = cursor.lastrowid  

#         # Insert cart items into OrderItem table and link to the new order group
#         for item in cart_items:
#             cursor.execute("INSERT INTO OrderItem (Transaction_ID, StockCode, OrdersStatus, Quantity, TotalItemPrice) VALUES (?, ?, ?, ?, ?)", (transaction_id, item.ProductID, 'Processing', item.CartQuantity, item.TotalItemPrice))

#         # Delete the cart items
#         cursor.execute("DELETE FROM ShoppingCart WHERE UserID = ?", (user_id,))

#         # Commit the transaction
#         connection.commit()

#         return {"success": "Checkout completed successfully.", "TransactionID": transaction_id}

#     except pyodbc.Error as e:
#         print(f"Database error during checkout: {e}")
#         connection.rollback()  # Rollback in case of error
#         return {"error": "Database error during checkout"}

#     finally:
#         if cursor:
#             cursor.close()
#         if connection:
#             connection.close()


def checkout_cart(user_id, cart_items, Location, total_price):
    try:
        connection = connect_db()
        # Ensures all operations are executed as a single transaction
        connection.autocommit = False
        cursor = connection.cursor()

        insert_order_group_stmt = """
            INSERT INTO OrderGroup (CustomerID, TotalPrice, TransactionDate, Location, OrdersStatus)
            OUTPUT INSERTED.OrderGroupID
            VALUES (?, ?, ?, ?, ?)
        """
        cursor.execute(insert_order_group_stmt, (user_id, total_price, datetime.now(), Location, 'Processing'))
        OrderGroupID = cursor.fetchone()[0]  

        # Insert cart items into the OrderItem table and link them to the new order group
        for item in cart_items:
            cursor.execute("""
                INSERT INTO OrderItem (OrderGroupID,  ProductID, Quantity, UnitPrice, TotalItemPrice)
                VALUES (?, ?, ?, ?, ?)
            """, (OrderGroupID, item['ProductID'], item['CartQuantity'], item['UnitPrice'], item['TotalItemPrice']))

        # Delete the cart items from the ShoppingCart table
        cursor.execute("DELETE FROM ShoppingCart WHERE UserID = ?", (user_id,))

        # Commit the transaction
        connection.commit()

        return {"success": "Checkout completed successfully.", "OrderID": OrderGroupID}

    except pyodbc.Error as e:
        print(f"Database error during checkout: {e}")
        connection.rollback()  # Rollback in case of an error
        return {"error": "Database error during checkout"}

    finally:
        if cursor:
            cursor.close()
        if connection:
            connection.close()


